onvif-faraz
============

ONVIF Client Implementation in Python

Dependencies
------------
compatible with python3.9

`suds <https://pypi.python.org/pypi/suds>`_ >= 0.4

`wsdiscovery`

Install onvif-faraz
--------------------
**From Source**

You should clone this repository and run setup.py::

    pip install git+https://git.sensifai.com/sdk/onvif-python

::

